# Group

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**data** | **list[int]** | The data value provided in array of integer values. | [optional] 
**groups** | [**Groups**](Groups.md) |  | [optional] 
**name** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


